@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client;
 # ABSTRACT: A comprehensive, DWIM-featured client to the MetaCPAN API
-$MetaCPAN::Client::VERSION = '2.020000';
+$MetaCPAN::Client::VERSION = '2.021000';
 use Moo;
 use Carp;
 use Ref::Util qw< is_arrayref is_hashref >;
@@ -174,9 +174,10 @@ sub all {
     my $type   = shift;
     my $params = shift;
 
-    grep { $type eq $_ } qw/ authors distributions modules releases
-                             favorites ratings mirrors files package /
-        or croak "all: unsupported type";
+    # This endpoint used to support only pluralized types (mostly) and convert
+    # to singular types before redispatching.  Now it accepts both plural and
+    # unplural forms directly and relies on the underlying methods it
+    # dispatches to to check types (using the global supported types array).
     $type =~ s/s$//;
 
     $params and !is_hashref($params)
@@ -412,7 +413,7 @@ MetaCPAN::Client - A comprehensive, DWIM-featured client to the MetaCPAN API
 
 =head1 VERSION
 
-version 2.020000
+version 2.021000
 
 =head1 SYNOPSIS
 
@@ -700,6 +701,15 @@ get an iterator back to fetch one object at a time.
 
     my $module = $mcpan->all('releases', { scroller_size => 500 });
 
+=head3 sort
+
+Pass a raw Elasticsearch sort specification for the query.
+
+    my $some_releases = $mcpan->all('releases', { sort => [{ date => { order => 'desc' } }] })
+
+Note: this param and is a bit too specific to Elasticsearch.  Just like
+L</es_filter>, only use this if you know what you're dealing with.
+
 =head1 SEARCH SPEC
 
 The hash-based search spec is common to many searches. It is quite
