@@ -2,18 +2,19 @@ use strict;
 use warnings;
 package MetaCPAN::Client::Types;
 # ABSTRACT: type checking helper class
-$MetaCPAN::Client::Types::VERSION = '2.020000';
+$MetaCPAN::Client::Types::VERSION = '2.021000';
 use Type::Tiny      ();
 use Types::Standard ();
 use Ref::Util qw< is_ref >;
 
 use parent 'Exporter';
-our @EXPORT_OK = qw< Str Int Time ArrayRef HashRef >;
+our @EXPORT_OK = qw< Str Int Time ArrayRef HashRef Bool >;
 
 sub Str      { Types::Standard::Str      }
 sub Int      { Types::Standard::Int      }
 sub ArrayRef { Types::Standard::ArrayRef }
 sub HashRef  { Types::Standard::HashRef  }
+sub Bool     { Types::Standard::Bool     }
 
 sub Time {
     return Type::Tiny->new(
@@ -37,12 +38,14 @@ MetaCPAN::Client::Types - type checking helper class
 
 =head1 VERSION
 
-version 2.020000
+version 2.021000
 
 =head1 METHODS
 
 =head2 ArrayRef
 
+=head2 Bool
+
 =head2 HashRef
 
 =head2 Int
